@@ -12,6 +12,10 @@
 #'
 #' @param outcome Any non-character vector. Factors will be converted
 #' to numeric via coercion.
+#' @param true_bounds Specify this parameter with the lower and upper bound
+#'        if the observed min/max of the outcome should not be used. Useful when
+#'        an upper or lower bound exists but the observed data is less than/more than
+#'        that bound. The normalization function will respect these bounds.
 #' @return A numeric vector with an upper bound of 1 and a lower bound of
 #' 0. The original bounds are saved in the attributes "lower_bound" and
 #' "upper_bound".
@@ -29,16 +33,18 @@
 #'   normalize(outcome=c('a','b'))
 #' }
 #' @export
-normalize <- function(outcome) {
+normalize <- function(outcome,true_bounds=NULL) {
 
   if(is.character(outcome)) {
 
-    stop("Please do not pass a character vector to the function.\nThat really doesn't make any sense.")
+    stop("Please do not pass a character vector as a response/outcome.\nThat really doesn't make any sense.")
 
   }
 
   if(is.factor(outcome)) {
 
+    print("Converting factor response variable to numeric.")
+
     outcome <- as.numeric(outcome)
 
   }
@@ -49,12 +55,26 @@ normalize <- function(outcome) {
 
   }
 
-  trans_out <- (outcome - min(outcome, na.rm=T)) / (max(outcome, na.rm=T) - min(outcome, na.rm=T))
+  if(!is.null(true_bounds)) {
+
+    min_out <- true_bounds[1]
+    max_out <- true_bounds[2]
+  } else {
+
+    min_out <- min(outcome, na.rm=T)
+    max_out <- max(outcome, na.rm=T)
+
+    print(paste0("Normalizing using the observed bounds of ",min_out, " - ",
+                 max_out,". If these are incorrect, please pass the bounds to use to the true_bounds parameter."))
+
+  }
+
+  trans_out <- (outcome - min_out) / (max_out - min_out)
 
   # handle values very close to 0
 
-  attr(trans_out, "upper_bound") <- max(outcome, na.rm=T)
-  attr(trans_out, "lower_bound") <- min(outcome, na.rm=T)
+  attr(trans_out, "upper_bound") <- max_out
+  attr(trans_out, "lower_bound") <- min_out
 
   return(trans_out)
 
